# Harakiri

> 만당에 온 걸 환영한다

[만당 API](https://github.com/ManjiKR/ManjiApi) 래퍼

## 설치

```
pip install Harakiri
```

## 사용

```py
import harakiri

client = harakiri.Client()
```

### Manji

[프론트엔드](https://github.com/ManjiKR/Manji)
[백엔드](https://github.com/ManjiKR/ManjiApi)
[데이터](https://github.com/ManjiKR/yoshimitsu_frame_data)
